from setuptools import setup

setup(name='drsDistributions',
      version='0.1',
      description='Package to deal with probability distributions',
      packages=['drsDistributions'],
      zip_safe=False)
